@@ -1,6 +1,7 @@
 import pathlib
 
 import pandas as pd
+import requests
 
 from oda_data import config
 from oda_data.clean_data.common import read_settings, clean_raw_df
@@ -31,7 +32,7 @@ def _download(file_url: str, year: int) -> pd.DataFrame:
     logger.info(f"Downloading CRS data for {year}... This may take a while.")
 
     # Get file content
-    file_content = common.get_zip(file_url)
+    file_content: requests.Response = common.get_zip(file_url)
 
     return common.read_zip_content(
         request_content=file_content, file_name=f"CRS {year} data.txt"
@@ -59,7 +60,7 @@ def download_crs(years: int | list | range, small_version: bool = False) -> None
         _save(
             df=df,
             year=year,
-            config_file_path=config.OdaPATHS.cleaning_config / "crs_config.json",
+            config_file_path=config.OdaPATHS.settings / "crs_config.json",
             save_path=config.OdaPATHS.raw_data,
             small_version=small_version,
         )
